@@ -2,7 +2,7 @@ import random
 import shutil
 from pathlib import Path
 from subprocess import PIPE, call
-from typing import Any, Dict, Iterator, List, Optional, Union, cast
+from typing import Dict, Iterator, List, Optional, Union, cast
 
 from ape._compat import Literal
 from ape.api import (
@@ -298,12 +298,8 @@ class HardhatProvider(SubprocessProvider, Web3Provider, TestProviderAPI):
             str(self.port),
         ]
 
-    def _make_request(self, rpc: str, args: list) -> Any:
-        return self.web3.provider.make_request(rpc, args)  # type: ignore
-
     def set_block_gas_limit(self, gas_limit: int) -> bool:
-        result = self._make_request("evm_setBlockGasLimit", [hex(gas_limit)])
-        return result.get("result") is True
+        return self._make_request("evm_setBlockGasLimit", [hex(gas_limit)]) is True
 
     def set_timestamp(self, new_timestamp: int):
         pending_timestamp = self.get_block("pending").timestamp
@@ -316,23 +312,20 @@ class HardhatProvider(SubprocessProvider, Web3Provider, TestProviderAPI):
         self._make_request("hardhat_mine", [num_blocks_arg])
 
     def snapshot(self) -> str:
-        result = self._make_request("evm_snapshot", [])
-        return result["result"]
+        return self._make_request("evm_snapshot", [])
 
     def revert(self, snapshot_id: SnapshotID) -> bool:
         if isinstance(snapshot_id, int):
             snapshot_id = HexBytes(snapshot_id).hex()
 
-        result = self._make_request("evm_revert", [snapshot_id])
-        return result.get("result") is True
+        return self._make_request("evm_revert", [snapshot_id]) is True
 
     def unlock_account(self, address: AddressType) -> bool:
         result = self._make_request("hardhat_impersonateAccount", [address])
-
         if result:
             self.unlocked_accounts.append(address)
 
-        return result.get("result") is True
+        return result is True
 
     def send_transaction(self, txn: TransactionAPI) -> ReceiptAPI:
         """
@@ -439,7 +432,12 @@ class HardhatForkProvider(HardhatProvider):
 
     @property
     def fork_url(self) -> str:
-        return self._upstream_provider.connection_str  # type: ignore
+        if not isinstance(self._upstream_provider, UpstreamProvider):
+            raise HardhatProviderError(
+                f"Provider '{self._upstream_provider.name}' is not an upstream provider."
+            )
+
+        return self._upstream_provider.connection_str
 
     @property
     def fork_block_number(self) -> Optional[int]:
@@ -457,14 +455,6 @@ class HardhatForkProvider(HardhatProvider):
     def _fork_config(self) -> HardhatForkConfig:
         config = cast(HardhatNetworkConfig, self.config)
 
-        # NOTE: Only for backwards compatibility
-        if "mainnet_fork" in config.dict():
-            logger.warning(
-                "Use of key `mainnet_fork` in `hardhat` config is deprecated. "
-                "Please use the `fork` key, with `ecosystem` and `network` subkeys."
-            )
-            return HardhatForkConfig.parse_obj(config.dict().get("mainnet_fork"))
-
         ecosystem_name = self.network.ecosystem.name
         if ecosystem_name not in config.fork:
             return HardhatForkConfig()  # Just use default
@@ -502,11 +492,6 @@ class HardhatForkProvider(HardhatProvider):
             )
 
     def build_command(self) -> List[str]:
-        if not isinstance(self._upstream_provider, UpstreamProvider):
-            raise HardhatProviderError(
-                f"Provider '{self._upstream_provider.name}' is not an upstream provider."
-            )
-
         if not self.fork_url:
             raise HardhatProviderError("Upstream provider does not have a ``connection_str``.")
 
